@@ -1,5 +1,4 @@
 import json
-import logging
 from asyncio import sleep
 from copy import copy
 from datetime import datetime
@@ -84,7 +83,6 @@ from neuralspace.nlu.constants import (
 )
 from neuralspace.utils import get_auth_token, is_success_status, print_ner_response
 
-logger = logging.getLogger(__name__)
 console = Console()
 
 
@@ -107,7 +105,7 @@ async def get_languages() -> Dict[Text, Any]:
         else:
             console.print("> [red]ERROR[/red] ❌ Failed to create project")
             console.print(
-                f"😔 Platform response: \n{json.dumps(json_response, indent=4)}"
+                f'''> Reason for failure 😔: " [red]{json_response['message']}[/red] "'''
             )
     return json_response
 
@@ -138,7 +136,7 @@ async def create_project(project_name: Text, languages: List[Text]) -> Dict[Text
             )
             console.print(
                 "> [deep_sky_blue2]INFO[/deep_sky_blue2] "
-                "Here 💁 is your project information..."
+                "💁 Here is your project information..."
             )
             table.add_column("Name")
             table.add_column("Language")
@@ -163,7 +161,9 @@ async def create_project(project_name: Text, languages: List[Text]) -> Dict[Text
             )
         else:
             console.print("> [red]ERROR[/red] ❌ Failed to create project")
-            console.print(f"> 😔[red]{json_response[DATA]['error']}[/red]")
+            console.print(
+                f'''> Reason for failure 😔:- " [red]{json_response[DATA]['error']}[/red] "'''
+            )
     return json_response
 
 
@@ -187,7 +187,7 @@ async def delete_project(project_id: Text) -> Dict[Text, Any]:
         else:
             console.print("> [red]ERROR[/red] ❌ Failed to delete projects")
             console.print(
-                f"😔 Platform response: \n{json.dumps(json_response, indent=4)}"
+                f"> Reason for failure 😔:- [red]{json_response['message']}[/red]"
             )
     return json_response
 
@@ -237,9 +237,12 @@ async def list_projects(
                 f"with Page Size: {page_size}"
             )
             print_projects_table(json_response, verbose)
+            console.print(f"⏩ To upload your dataset: {UPLOAD_DATASET_COMMAND}")
         else:
             console.print("> [red]ERROR[/red] ❌ Failed to list projects")
-            console.print(f"Platform response: \n{json.dumps(json_response, indent=4)}")
+            console.print(
+                f'''> Reason for failure 😔: " [red]{json_response['message']}[/red] "'''
+            )
     return json_response
 
 
@@ -276,7 +279,7 @@ async def list_examples(
     console.print(
         f"> [deep_sky_blue2]INFO[/deep_sky_blue2] ⬇️ Fetching Examples with filter: \n"
         f"> [deep_sky_blue2]INFO[/deep_sky_blue2] #️⃣ [bold]Project ID:[/bold] [orange]{project_id}[orange]\n"
-        f"> [deep_sky_blue2]INFO[/deep_sky_blue2] ✏️ Language: {language}\n"
+        f"> [deep_sky_blue2]INFO[/deep_sky_blue2] 🕉️ Language: {language}\n"
         f"> [deep_sky_blue2]INFO[/deep_sky_blue2] 🍲 Prepared: {prepared}\n"
         f"> [deep_sky_blue2]INFO[/deep_sky_blue2] 📌 type: {type}"
     )
@@ -306,7 +309,7 @@ async def list_examples(
         else:
             console.print("> [red]ERROR[/red] ❌ Failed to list examples")
             console.print(
-                f"> Platform response: \n{json.dumps(json_response, indent=4)}"
+                f'''> Reason for failure 😔: " [red]{json_response['message']}[/red] "'''
             )
     return json_response
 
@@ -403,7 +406,7 @@ async def list_models(
         else:
             console.print("> [red]ERROR[/red] ❌ Failed to list models")
             console.print(
-                f"> Platform response: \n{json.dumps(json_response, indent=4)}"
+                f'''> Reason for failure 😔: " [red]{json_response['message']}[/red] "'''
             )
     return json_response
 
@@ -428,7 +431,7 @@ async def delete_examples(example_ids: List[Text]) -> Dict[Text, Any]:
         else:
             console.print("> [red]ERROR[/red] ❌ Failed to delete examples")
             console.print(
-                f"> Platform response: \n{json.dumps(json_response, indent=4)}"
+                f'''> Reason for failure 😔: " [red]{json_response['message']}[/red] "'''
             )
     return json_response
 
@@ -476,7 +479,7 @@ async def upload_dataset(
                     f"> Failed on example: \n{json.dumps(example, indent=4, ensure_ascii=False)}"
                 )
                 console.print(
-                    f"> Platform response: \n{json.dumps(json_response, indent=4)}"
+                    f'''> Reason for failure 😔: " [red]{json_response['message']}[/red] "'''
                 )
                 error_examples.append(example)
                 if ignore_errors:
@@ -534,7 +537,7 @@ async def wait_till_training_completes(
                             "> [red]ERROR[/red] Failed to fetch model details"
                         )
                         console.print(
-                            f"> [red]ERROR[/red] Platform Response: \n {json.dumps(json_response, indent=4)}"
+                            f'''> Reason for failure 😔: " [red]{json_response['message']}[/red] "'''
                         )
                         break
                     status.update(f"Model is {current_status} 🧍")
@@ -606,7 +609,7 @@ async def delete_models(model_id: Text) -> Dict[Text, Any]:
         else:
             console.print("> [red]ERROR[/red] ❌ Failed to delete models")
             console.print(
-                f"> Platform response: \n {json.dumps(json_response, indent=4)}"
+                f'''> Reason for failure 😔: " [red]{json_response['message']}[/red] "'''
             )
     return json_response
 
@@ -635,7 +638,7 @@ async def deploy(model_id: Text, n_replicas: int) -> Dict[Text, Any]:
         else:
             console.print("> [red]ERROR[/red] ❌ Failed to deploy model")
             console.print(
-                f"> Platform response: \n{json.dumps(json_response, indent=4)}"
+                f'''> Reason for failure 😔: " [red]{json_response['message']}[/red] "'''
             )
     return json_response
 
@@ -700,6 +703,6 @@ async def parse(model_id: Text, input_text: Text) -> Dict[Text, Any]:
         else:
             console.print("> [red]ERROR[/red] ❌ Failed to parse model")
             console.print(
-                f"> Platform response: \n{json.dumps(json_response, indent=4)}"
+                f'''> Reason for failure 😔: " [red]{json_response['message']}[/red] "'''
             )
     return json_response
